summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorvrouvrea <vrouvrea@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2015-10-02 09:34:09 +0000
committervrouvrea <vrouvrea@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2015-10-02 09:34:09 +0000
commitba47def14a25fb1299ef0980366c2c5479fb1ccc (patch)
tree7a8370706814d00698ec6c31a10aeaf22e079b23 /src
parent89d8caff43f3c38ee3ce3fd96000eaa549ba0481 (diff)
Review fix
git-svn-id: svn+ssh://scm.gforge.inria.fr/svnroot/gudhi/branches/alphashapes@816 636b058d-ea47-450e-bf9e-a15bfbe3eedb Former-commit-id: d112bf6b1b07a75947392576baa53321326e65c4
Diffstat (limited to 'src')
-rw-r--r--src/Alpha_complex/doc/Intro_alpha_complex.h8
-rw-r--r--src/Alpha_complex/example/Alpha_complex_from_off.cpp8
-rw-r--r--src/Alpha_complex/test/Alpha_complex_unit_test.cpp4
-rw-r--r--src/common/example/Delaunay_triangulation_off_rw.cpp5
-rw-r--r--src/common/include/gudhi/Delaunay_triangulation_off_io.h24
5 files changed, 23 insertions, 26 deletions
diff --git a/src/Alpha_complex/doc/Intro_alpha_complex.h b/src/Alpha_complex/doc/Intro_alpha_complex.h
index d266219b..2cb37578 100644
--- a/src/Alpha_complex/doc/Intro_alpha_complex.h
+++ b/src/Alpha_complex/doc/Intro_alpha_complex.h
@@ -93,8 +93,8 @@ namespace alphacomplex {
* \end{algorithmic}
* \f}
*
- * From the example above, it means the algorithm will look into each triangulation ([1,2,3], [2,3,4], [1,3,5], ...),
- * will compute the filtration value of the triangulation, and then will propagate the filtration value as described
+ * From the example above, it means the algorithm will look into each triangle ([1,2,3], [2,3,4], [1,3,5], ...),
+ * will compute the filtration value of the triangle, and then will propagate the filtration value as described
* here :
* \image html "alpha_complex_doc_135.png" "Filtration value propagation example"
* Then, the algorithm will look into each edge ([1,2], [2,3], [1,3], ...),
@@ -105,8 +105,8 @@ namespace alphacomplex {
*
* \section alpha-shape Alpha shape
*
- * In the example above, the alpha shape of \f$\alpha^2_{74} < \alpha^2 < \alpha^2_{73}\f$ is the alpha complex where the
- * \f$\alpha^2_{74} <\f$ filtration value \f$< \alpha^2_{73}\f$ as described in \cite AlphaShapesIntroduction
+ * In the example above, the alpha shape of \f$\alpha^2_{63} < \alpha^2 < \alpha^2_{62}\f$ is the alpha complex where the
+ * \f$\alpha^2_{63} <\f$ filtration value \f$< \alpha^2_{62}\f$ as described in \cite AlphaShapesIntroduction
*
* \image html "alpha_complex_doc_alpha_shape.png" "Alpha shape example"
* \copyright GNU General Public License v3.
diff --git a/src/Alpha_complex/example/Alpha_complex_from_off.cpp b/src/Alpha_complex/example/Alpha_complex_from_off.cpp
index b698d6d7..e140fe3d 100644
--- a/src/Alpha_complex/example/Alpha_complex_from_off.cpp
+++ b/src/Alpha_complex/example/Alpha_complex_from_off.cpp
@@ -1,11 +1,9 @@
-#include <stdio.h>
-#include <stdlib.h>
-
+#include <iostream>
#include <string>
// to construct a Delaunay_triangulation from a OFF file
-#include "gudhi/Delaunay_triangulation_off_io.h"
-#include "gudhi/Alpha_complex.h"
+#include <gudhi/Delaunay_triangulation_off_io.h>
+#include <gudhi/Alpha_complex.h>
void usage(char * const progName) {
std::cerr << "Usage: " << progName << " filename.off alpha_square_max_value" << std::endl;
diff --git a/src/Alpha_complex/test/Alpha_complex_unit_test.cpp b/src/Alpha_complex/test/Alpha_complex_unit_test.cpp
index 7a0800e4..b630e999 100644
--- a/src/Alpha_complex/test/Alpha_complex_unit_test.cpp
+++ b/src/Alpha_complex/test/Alpha_complex_unit_test.cpp
@@ -33,8 +33,8 @@
#include <vector>
// to construct a Delaunay_triangulation from a OFF file
-#include "gudhi/Delaunay_triangulation_off_io.h"
-#include "gudhi/Alpha_complex.h"
+#include <gudhi/Delaunay_triangulation_off_io.h>
+#include <gudhi/Alpha_complex.h>
// Use dynamic_dimension_tag for the user to be able to set dimension
typedef CGAL::Epick_d< CGAL::Dynamic_dimension_tag > Kernel_d;
diff --git a/src/common/example/Delaunay_triangulation_off_rw.cpp b/src/common/example/Delaunay_triangulation_off_rw.cpp
index d1aa7988..75e4fafb 100644
--- a/src/common/example/Delaunay_triangulation_off_rw.cpp
+++ b/src/common/example/Delaunay_triangulation_off_rw.cpp
@@ -1,11 +1,10 @@
// to construct a Delaunay_triangulation from a OFF file
-#include "gudhi/Delaunay_triangulation_off_io.h"
+#include <gudhi/Delaunay_triangulation_off_io.h>
#include <CGAL/Delaunay_triangulation.h>
#include <CGAL/Epick_d.h>
-#include <stdio.h>
-#include <stdlib.h>
+#include <iostream>
#include <string>
// Use dynamic_dimension_tag for the user to be able to set dimension
diff --git a/src/common/include/gudhi/Delaunay_triangulation_off_io.h b/src/common/include/gudhi/Delaunay_triangulation_off_io.h
index de5fa2af..0c5474c9 100644
--- a/src/common/include/gudhi/Delaunay_triangulation_off_io.h
+++ b/src/common/include/gudhi/Delaunay_triangulation_off_io.h
@@ -39,7 +39,7 @@ namespace Gudhi {
template<typename Complex>
class Delaunay_triangulation_off_visitor_reader {
private:
- Complex* _complex;
+ Complex* complex_;
typedef typename Complex::Point Point;
public:
@@ -48,10 +48,10 @@ class Delaunay_triangulation_off_visitor_reader {
/** \brief Delaunay_triangulation_off_visitor_reader constructor
*
* @param[in] _complex_ptr pointer on a Delaunay triangulation.
*/
- Delaunay_triangulation_off_visitor_reader(Complex* _complex_ptr)
- : _complex(nullptr) { }
+ Delaunay_triangulation_off_visitor_reader(Complex* complex_ptr_)
+ : complex_(nullptr) { }
/** \brief Off_reader visitor init implementation.
*
@@ -77,7 +77,7 @@ class Delaunay_triangulation_off_visitor_reader {
"file for Delaunay triangulation - edges are computed." << std::endl;
}
// Complex construction with dimension from file
- _complex = new Complex(dim);
+ complex_ = new Complex(dim);
}
/** \brief Off_reader visitor point implementation.
@@ -95,7 +95,7 @@ class Delaunay_triangulation_off_visitor_reader {
}
std::cout << std::endl;
#endif // DEBUG_TRACES
- _complex->insert(Point(point.size(), point.begin(), point.end()));
+ complex_->insert(Point(point.size(), point.begin(), point.end()));
}
// Off_reader visitor maximal_face implementation - not used
@@ -115,7 +115,7 @@ class Delaunay_triangulation_off_visitor_reader {
* @warning The returned pointer can be nullptr.
*/
Complex* get_complex() const {
- return _complex;
+ return complex_;
}
};
@@ -157,12 +157,12 @@ class Delaunay_triangulation_off_reader {
: valid_(false) {
std::ifstream stream(name_file);
if (stream.is_open()) {
- Delaunay_triangulation_off_visitor_reader<Complex> off_visitor(_complex);
+ Delaunay_triangulation_off_visitor_reader<Complex> off_visitor(complex_);
Off_reader off_reader(stream);
valid_ = off_reader.read(off_visitor);
if (valid_) {
- _complex = off_visitor.get_complex();
- if (_complex == nullptr) {
+ complex_ = off_visitor.get_complex();
+ if (complex_ == nullptr) {
std::cerr << "Delaunay_triangulation_off_reader::Delaunay_triangulation_off_reader off_visitor returns an empty pointer" << std::endl;
valid_ = false;
}
@@ -190,7 +190,7 @@ class Delaunay_triangulation_off_reader {
*/
Complex* get_complex() const {
if (valid_)
- return _complex;
+ return complex_;
return nullptr;
}
@@ -199,7 +199,7 @@ class Delaunay_triangulation_off_reader {
/** \brief OFF file read status.*/
bool valid_;
/** \brief A pointer on the Delaunay triangulation.*/
- Complex* _complex;
+ Complex* complex_;
};
/** \brief OFF file writer from a Delaunay triangulation.
@@ -48,10 +48,10 @@ class Delaunay_triangulation_off_visitor_reader {
/** \brief Delaunay_triangulation_off_visitor_reader constructor
*
- * @param[in] _complex_ptr pointer on a Delaunay triangulation.
+ * @param[in] complex_ptr_ pointer on a Delaunay triangulation.
*/